@@ -22,6 +22,7 @@ extern NSString *const VLCPlaybackServicePlaybackDidFail;
 extern NSString *const VLCPlaybackServicePlaybackMetadataDidChange;
 extern NSString *const VLCPlaybackServicePlaybackPositionUpdated;
 extern NSString *const VLCPlaybackServicePlaybackModeUpdated;
+extern NSString *const VLCPlaybackServiceShuffleModeUpdated;
 extern NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem;
 
 @class VLCPlaybackService;
@@ -54,6 +55,7 @@ NS_SWIFT_NAME(PlaybackService)
 @property (nonatomic, strong, nullable) UIView *videoOutputView;
 
 @property (nonatomic, retain) VLCMediaList *mediaList;
+@property (nonatomic, retain) VLCMediaList *shuffledList;
 
 /* returns nil if currently playing item is not available,*/
 
